# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: vehicle_config.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'vehicle_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14vehicle_config.proto\x12\rmdrive.common\"*\n\x07Point3D\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"<\n\nQuaternion\x12\n\n\x02qx\x18\x01 \x01(\x01\x12\n\n\x02qy\x18\x02 \x01(\x01\x12\n\n\x02qz\x18\x03 \x01(\x01\x12\n\n\x02qw\x18\x04 \x01(\x01\"\x91\x01\n\tTransform\x12\x14\n\x0csource_frame\x18\x01 \x01(\t\x12\x14\n\x0ctarget_frame\x18\x02 \x01(\t\x12+\n\x0btranslation\x18\x03 \x01(\x0b\x32\x16.mdrive.common.Point3D\x12+\n\x08rotation\x18\x04 \x01(\x0b\x32\x19.mdrive.common.Quaternion\"9\n\nExtrinsics\x12+\n\ttansforms\x18\x01 \x03(\x0b\x32\x18.mdrive.common.Transform\"U\n\rPinholeCamera\x12\r\n\x05width\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\x12\x11\n\tintrinsic\x18\x03 \x03(\x01\x12\x12\n\ndistortion\x18\x04 \x03(\x01\"U\n\rFisheyeCamera\x12\r\n\x05width\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\x12\x11\n\tintrinsic\x18\x03 \x03(\x01\x12\x12\n\ndistortion\x18\x04 \x03(\x01\"\xbe\x01\n\x0b\x43\x61meraParam\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x32\n\nmodel_type\x18\x02 \x01(\x0e\x32\x1e.mdrive.common.CameraModelType\x12/\n\x07pinhole\x18\x03 \x01(\x0b\x32\x1c.mdrive.common.PinholeCameraH\x00\x12/\n\x07\x66isheye\x18\x04 \x01(\x0b\x32\x1c.mdrive.common.FisheyeCameraH\x00\x42\x07\n\x05model\"?\n\nIntrinsics\x12\x31\n\rcamera_params\x18\x01 \x03(\x0b\x32\x1a.mdrive.common.CameraParam\"]\n\x0bVehicleInfo\x12\r\n\x05model\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0b\n\x03vin\x18\x03 \x01(\t\x12\r\n\x05plate\x18\x04 \x01(\t\x12\x17\n\x0fother_unique_id\x18\x05 \x01(\t\"^\n\x0cLatencyParam\x12\x11\n\tdead_time\x18\x01 \x01(\x01\x12\x11\n\trise_time\x18\x02 \x01(\x01\x12\x11\n\tpeak_time\x18\x03 \x01(\x01\x12\x15\n\rsettling_time\x18\x04 \x01(\x01\"\x90\t\n\x0cVehicleParam\x12\x1a\n\x12top_edge_to_center\x18\x01 \x01(\x01\x12\x1d\n\x15\x62ottom_edge_to_center\x18\x02 \x01(\x01\x12\x1c\n\x14\x66ront_edge_to_center\x18\x03 \x01(\x01\x12\x1b\n\x13\x62\x61\x63k_edge_to_center\x18\x04 \x01(\x01\x12\x1b\n\x13left_edge_to_center\x18\x05 \x01(\x01\x12\x1c\n\x14right_edge_to_center\x18\x06 \x01(\x01\x12\x0e\n\x06length\x18\x07 \x01(\x01\x12\r\n\x05width\x18\x08 \x01(\x01\x12\x0e\n\x06height\x18\t \x01(\x01\x12\x11\n\tmax_speed\x18\n \x01(\x01\x12\x17\n\x0fmin_turn_radius\x18\x0b \x01(\x01\x12\x18\n\x10max_acceleration\x18\x0c \x01(\x01\x12\x18\n\x10max_deceleration\x18\r \x01(\x01\x12\x18\n\x10max_engine_pedal\x18\x0e \x01(\x01\x12\x17\n\x0fmax_brake_pedal\x18\x0f \x01(\x01\x12\x17\n\x0fmax_steer_angle\x18\x10 \x01(\x01\x12\x1c\n\x14max_steer_angle_rate\x18\x11 \x01(\x01\x12\x1c\n\x14min_steer_angle_rate\x18\x12 \x01(\x01\x12\x13\n\x0bsteer_ratio\x18\x13 \x01(\x01\x12\x12\n\nwheel_base\x18\x14 \x01(\x01\x12\x1c\n\x14wheel_rolling_radius\x18\x15 \x01(\x01\x12\x13\n\x0b\x64rive_ratio\x18( \x01(\x01\x12\x1a\n\x12total_vehicle_mass\x18) \x01(\x02\x12\"\n\x1amax_abs_speed_when_stopped\x18\x16 \x01(\x02\x12 \n\x18min_abs_speed_when_start\x18\x17 \x01(\x02\x12\x16\n\x0e\x62rake_deadzone\x18\x18 \x01(\x01\x12\x19\n\x11throttle_deadzone\x18\x19 \x01(\x01\x12;\n\x16steering_latency_param\x18\x1a \x01(\x0b\x32\x1b.mdrive.common.LatencyParam\x12;\n\x16throttle_latency_param\x18\x1b \x01(\x0b\x32\x1b.mdrive.common.LatencyParam\x12\x38\n\x13\x62rake_latency_param\x18\x1c \x01(\x0b\x32\x1b.mdrive.common.LatencyParam\x12\x1f\n\x17steer_zero_offset_angle\x18\x1d \x01(\x01\x12\x16\n\x0esteer_deadband\x18\x1e \x01(\x01\x12\x1a\n\x12steer_lqr_deadband\x18\x1f \x01(\x01\x12\x16\n\x0esteer_ratio_a0\x18  \x01(\x01\x12\x16\n\x0esteer_ratio_a1\x18! \x01(\x01\x12\x16\n\x0esteer_ratio_a2\x18\" \x01(\x01\x12\x16\n\x0esteer_ratio_a3\x18# \x01(\x01\x12\x16\n\x0esteer_ratio_a4\x18$ \x01(\x01\x12\x16\n\x0esteer_ratio_a5\x18% \x01(\x01\x12\x16\n\x0esteer_ratio_a6\x18& \x01(\x01\x12\x16\n\x0esteer_ratio_a7\x18\' \x01(\x01\"\xd3\x01\n\rVehicleConfig\x12\x30\n\x0cvehicle_info\x18\x01 \x01(\x0b\x32\x1a.mdrive.common.VehicleInfo\x12\x32\n\rvehicle_param\x18\x02 \x01(\x0b\x32\x1b.mdrive.common.VehicleParam\x12-\n\nextrinsics\x18\x03 \x01(\x0b\x32\x19.mdrive.common.Extrinsics\x12-\n\nintrinsics\x18\x04 \x01(\x0b\x32\x19.mdrive.common.Intrinsics*+\n\x0f\x43\x61meraModelType\x12\x0b\n\x07PINHOLE\x10\x00\x12\x0b\n\x07\x46ISHEYE\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vehicle_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CAMERAMODELTYPE']._serialized_start=2360
  _globals['_CAMERAMODELTYPE']._serialized_end=2403
  _globals['_POINT3D']._serialized_start=39
  _globals['_POINT3D']._serialized_end=81
  _globals['_QUATERNION']._serialized_start=83
  _globals['_QUATERNION']._serialized_end=143
  _globals['_TRANSFORM']._serialized_start=146
  _globals['_TRANSFORM']._serialized_end=291
  _globals['_EXTRINSICS']._serialized_start=293
  _globals['_EXTRINSICS']._serialized_end=350
  _globals['_PINHOLECAMERA']._serialized_start=352
  _globals['_PINHOLECAMERA']._serialized_end=437
  _globals['_FISHEYECAMERA']._serialized_start=439
  _globals['_FISHEYECAMERA']._serialized_end=524
  _globals['_CAMERAPARAM']._serialized_start=527
  _globals['_CAMERAPARAM']._serialized_end=717
  _globals['_INTRINSICS']._serialized_start=719
  _globals['_INTRINSICS']._serialized_end=782
  _globals['_VEHICLEINFO']._serialized_start=784
  _globals['_VEHICLEINFO']._serialized_end=877
  _globals['_LATENCYPARAM']._serialized_start=879
  _globals['_LATENCYPARAM']._serialized_end=973
  _globals['_VEHICLEPARAM']._serialized_start=976
  _globals['_VEHICLEPARAM']._serialized_end=2144
  _globals['_VEHICLECONFIG']._serialized_start=2147
  _globals['_VEHICLECONFIG']._serialized_end=2358
# @@protoc_insertion_point(module_scope)
